@@ -153,7 +153,8 @@ export function detectBrowser(window) {
   const result = {browser: null, version: null};
 
   // Fail early if it's not a browser
-  if (typeof window === 'undefined' || !window.navigator) {
+  if (typeof window === 'undefined' || !window.navigator ||
+      !window.navigator.userAgent) {
     result.browser = 'Not a browser.';
     return result;
   }
